Congestion Vessels
------------------

.. note::
    available on platforms : Platform.Liquids, Platform.LNG, Platform.LPG, Platform.Dry

.. autoclass:: kpler.sdk.resources.congestion_vessels.CongestionVessels
    :members:

.. autoclass:: kpler.sdk.VesselTypesCPP
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesOil
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLNG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLPG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesDry
    :members:
    :noindex:

.. autoclass:: kpler.sdk.CongestionVesselsOperation
    :members:

.. autoclass:: kpler.sdk.CongestionVesselsPeriod
    :members:
